@@ -3,8 +3,20 @@ import httpx
 from pysirix.sirix import Sirix
 from pysirix.database import Database
 from pysirix.resource import Resource
+from pysirix.json_store import JsonStoreSync, JsonStoreAsync
 from pysirix.constants import Insert, DBType
 from pysirix.errors import SirixServerError
+from pysirix.types import (
+    QueryResult,
+    Commit,
+    Revision,
+    InsertDiff,
+    ReplaceDiff,
+    UpdateDiff,
+    DeleteDiff,
+    Metadata,
+    MetaNode,
+)
 
 
 def sirix_sync(username: str, password: str, client: httpx.Client,) -> Sirix:
@@ -40,6 +52,17 @@ __all__ = [
     "SirixServerError",
     "Database",
     "Resource",
+    "JsonStoreSync",
+    "JsonStoreAsync",
     "Insert",
     "DBType",
+    "QueryResult",
+    "Commit",
+    "Revision",
+    "InsertDiff",
+    "ReplaceDiff",
+    "UpdateDiff",
+    "DeleteDiff",
+    "Metadata",
+    "MetaNode",
 ]
